@@ -1,29 +1,28 @@
 #!/usr/bin/env python
 
-from collections import defaultdict
 import sys
-
 import html5lib
 
+from collections import defaultdict
+
+
 try:
     import json
 except ImportError:
     import simplejson as json
 
 
-def get_items(location, encoding='UTF-8'):
+def get_items(location, encoding=None):
     """
-    Pass in a file or file-like object and get a list of Items present in the
+    Pass in a string or file-like object and get a list of Items present in the
     HTML document.
     """
     dom_builder = html5lib.treebuilders.getTreeBuilder("dom")
     parser = html5lib.HTMLParser(tree=dom_builder)
-    
-    if (sys.version_info.major == 3):
-        tree = parser.parse(location)
+    if encoding:
+        tree = parser.parse(location, transport_encoding=encoding)
     else:
-        tree = parser.parse(location, encoding=encoding)
-    
+        tree = parser.parse(location)
     return _find_items(tree)
 
 
@@ -165,12 +164,15 @@ def _extract(e, item):
         itemprop = _attr(child, "itemprop")
         itemscope = _is_itemscope(child)
         if itemprop and itemscope:
-            nested_item = _make_item(child)
-            unlinked.extend(_extract(child, nested_item))
-            item.set(itemprop, nested_item)
+            for i in itemprop.split(" "):
+                nested_item = _make_item(child)
+                unlinked.extend(_extract(child, nested_item))
+                item.set(i, nested_item)
         elif itemprop:
             value = _property_value(child)
-            item.set(itemprop, value)
+            # itemprops may also be in a space delimited list
+            for i in itemprop.split(" "):
+                item.set(i, value)
             unlinked.extend(_extract(child, item))
         elif itemscope:
             unlinked.append(child)
@@ -204,7 +206,7 @@ def _property_value(e):
     elif attrib:
         value = e.getAttribute(attrib)
     else:
-        value = _text(e)
+        value = e.getAttribute("content") or _text(e)
     return value
 
 
@@ -212,6 +214,8 @@ def _text(e):
     chunks = []
     if e.nodeType == e.TEXT_NODE:
         chunks.append(e.data)
+    elif hasattr(e, 'tagName') and e.tagName == 'script':
+        return ''
     for child in e.childNodes:
         chunks.append(_text(child))
     return ''.join(chunks)
